==> ucdp-0.2.0.tar.gz: ucdp-0.2.0/tests/test_fileset.py <==
#
# MIT License
#
# Copyright (c) 2024 nbiotcloud
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
#
"""Test Module File Information."""

import ucdp as u


def test_basic(example_simple):
    """Basic Testing."""
    from uart.uart import UartMod

    mod = UartMod()

    info = u.FileSet.from_mod(mod, "hdl")
    assert info.target is None
    assert info.filepaths == (
        u.LibPath(libname="glbl", path=example_simple / "src" / "glbl" / "clk_gate" / "rtl" / "clk_gate.sv"),
        u.LibPath(libname="uart", path=example_simple / "src" / "uart" / "uart" / "rtl" / "uart_regf.sv"),
        u.LibPath(libname="uart", path=example_simple / "src" / "uart" / "uart" / "rtl" / "uart.sv"),
    )
    assert info.incdirs == ()

    info = u.FileSet.from_mod(mod, "systemc")
    assert info.target is None
    assert info.filepaths == ()
    assert info.incdirs == ()

==> ucdp-0.3.0.tar.gz: ucdp-0.3.0/tests/test_fileset.py <==
#
# MIT License
#
# Copyright (c) 2024 nbiotcloud
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
#
"""Test Module File Information."""

import ucdp as u


def test_basic(example_simple):
    """Basic Testing."""
    from uart_lib.uart import UartMod

    mod = UartMod()

    info = u.FileSet.from_mod(mod, "hdl")
    assert info.target is None
    assert info.filepaths == (
        u.LibPath(libname="glbl_lib", path=example_simple / "src" / "glbl_lib" / "clk_gate" / "rtl" / "clk_gate.sv"),
        u.LibPath(libname="uart_lib", path=example_simple / "src" / "uart_lib" / "uart" / "rtl" / "uart_regf.sv"),
        u.LibPath(libname="uart_lib", path=example_simple / "src" / "uart_lib" / "uart" / "rtl" / "uart_core.sv"),
        u.LibPath(libname="uart_lib", path=example_simple / "src" / "uart_lib" / "uart" / "rtl" / "uart.sv"),
    )
    assert info.inc_dirs == ()

    info = u.FileSet.from_mod(mod, "systemc")
    assert info.target is None
    assert info.filepaths == ()
    assert info.inc_dirs == ()
